@@ -24,6 +24,7 @@ import (
 	ctrl "sigs.k8s.io/controller-runtime"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/webhook"
+	"sigs.k8s.io/controller-runtime/pkg/webhook/admission"
 )
 
 // log is for logging in this package.
@@ -54,21 +55,21 @@ func (r *Fetcher) Default() {
 var _ webhook.Validator = &Fetcher{}
 
 // ValidateCreate implements webhook.Validator so a webhook will be registered for the type
-func (r *Fetcher) ValidateCreate() error {
+func (r *Fetcher) ValidateCreate() (admission.Warnings, error) {
 	fetcherlog.Info("validate create", "name", r.Name)
-	return r.validate()
+	return nil, r.validate()
 }
 
 // ValidateUpdate implements webhook.Validator so a webhook will be registered for the type
-func (r *Fetcher) ValidateUpdate(_ runtime.Object) error {
+func (r *Fetcher) ValidateUpdate(_ runtime.Object) (admission.Warnings, error) {
 	fetcherlog.Info("validate update", "name", r.Name)
-	return r.validate()
+	return nil, r.validate()
 }
 
 // ValidateDelete implements webhook.Validator so a webhook will be registered for the type
-func (r *Fetcher) ValidateDelete() error {
+func (r *Fetcher) ValidateDelete() (admission.Warnings, error) {
 	fetcherlog.Info("validate delete", "name", r.Name)
-	return nil
+	return nil, nil
 }
 
 func (r *Fetcher) validate() error {
