@@ -19,6 +19,11 @@ set -ex
 
 os=$(go env GOOS)
 arch=$(go env GOARCH)
-curl -L https://github.com/kubernetes-sigs/kubebuilder/releases/download/v2.3.1/kubebuilder_2.3.1_${os}_${arch}.tar.gz | tar -xz -C /tmp/
-sudo mv /tmp/kubebuilder_2.3.1_${os}_${arch} /usr/local/kubebuilder
+export K8S_VERSION=1.19.2
 export PATH=$PATH:/usr/local/kubebuilder/bin
+sudo mkdir -p /usr/local/kubebuilder/bin
+curl -sSLo kubebuilder https://github.com/kubernetes-sigs/kubebuilder/releases/download/v3.2.0/kubebuilder_${os}_${arch}
+sudo mv ./kubebuilder /usr/local/bin/
+
+curl -sSLo envtest-bins.tar.gz "https://go.kubebuilder.io/test-tools/${K8S_VERSION}/${os}/${arch}"
+sudo  tar -C /usr/local/kubebuilder --strip-components=1 -zvxf envtest-bins.tar.gz
\ No newline at end of file
