@@ -23,6 +23,7 @@ import (
 	"strings"
 
 	corev1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/runtime"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/webhook/admission"
@@ -42,6 +43,13 @@ type JavaagentInjector struct {
 	decoder *admission.Decoder
 }
 
+func NewJavaagentInjector(client client.Client, schema *runtime.Scheme) *JavaagentInjector {
+	return &JavaagentInjector{
+		Client:  client,
+		decoder: admission.NewDecoder(schema),
+	}
+}
+
 // Handle will process every coming pod under the
 // specified namespace which labeled "swck-injection=enabled"
 func (r *JavaagentInjector) Handle(ctx context.Context, req admission.Request) admission.Response {
@@ -97,12 +105,3 @@ func (r *JavaagentInjector) findMatchedSwAgentL(ctx context.Context, req admissi
 	swAgentList.Items = availableSwAgentL
 	return swAgentList
 }
-
-// Javaagent implements admission.DecoderInjector.
-// A decoder will be automatically injected.
-
-// InjectDecoder injects the decoder.
-func (r *JavaagentInjector) InjectDecoder(d *admission.Decoder) error {
-	r.decoder = d
-	return nil
-}
